@@ -7,19 +7,20 @@ import java.awt.event.WindowListener;
 import java.util.Locale;
 
 import javax.swing.ImageIcon;
+import javax.swing.JComponent;
 import javax.swing.JFrame;
 import javax.swing.JLabel;
 import javax.swing.JScrollPane;
 import javax.swing.JSplitPane;
 
 import org.af.commons.Localizer;
+import org.apache.commons.lang.ArrayUtils;
 import org.mutoss.config.Configuration;
 import org.mutoss.gui.datatable.CellEditorE;
 import org.mutoss.gui.datatable.CellValue;
 import org.mutoss.gui.datatable.DataFramePanel;
 import org.mutoss.gui.datatable.DataTable;
 import org.mutoss.gui.datatable.RDataFrameRef;
-import org.mutoss.gui.graph.ControlMGraph;
 import org.mutoss.gui.graph.GraphMCP;
 import org.mutoss.gui.graph.GraphView;
 import org.mutoss.gui.graph.PView;
@@ -28,14 +29,16 @@ public class CreateGraphGUI extends JFrame implements WindowListener {
 	
 	GraphMCP graph;
 	
-	public CreateGraphGUI(String graph, boolean debug, double grid) {
+	public CreateGraphGUI(String graph, double[] pvalues, boolean debug, double grid) {
 		super("Creating and modifying graphs");	
-		Locale.setDefault(Locale.ENGLISH);
+		Locale.setDefault(Locale.US);
+		JComponent.setDefaultLocale(Locale.US); 
 		RControl.getRControl(debug);
 		Localizer.getInstance().addResourceBundle("org.mutoss.gui.ResourceBundle");
 		Configuration.getInstance().getGeneralConfig().setGridSize((int)grid);
 		setIconImage((new ImageIcon(getClass().getResource("/org/mutoss/gui/graph/images/rjavaicon64.png"))).getImage());
-		agc = new ControlMGraph(graph, this);
+		agc = new GraphView(graph, this);		
+		
 		// Fenster in der Mitte des Bildschirms platzieren mit inset = 50 Pixeln Rand.
 		int inset = 50;
 		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
@@ -46,7 +49,9 @@ public class CreateGraphGUI extends JFrame implements WindowListener {
 		
 		setJMenuBar(new MenuBarMGraph(agc));
 		makeContent();
-		this.graph = new GraphMCP(graph, graphview.getVS());
+		this.graph = new GraphMCP(graph, agc.getVS());
+		
+		if (pvalues.length>0) getPView().setPValues(ArrayUtils.toObject(pvalues));
 		
 		setVisible(true);
 	}
@@ -64,29 +69,27 @@ public class CreateGraphGUI extends JFrame implements WindowListener {
 		CreateGraphGUI.grid = grid;
 		javax.swing.SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
-				new CreateGraphGUI(CreateGraphGUI.graphStr, CreateGraphGUI.debug, CreateGraphGUI.grid);
+				new CreateGraphGUI(CreateGraphGUI.graphStr, new double[] {}, CreateGraphGUI.debug, CreateGraphGUI.grid);
 			}
 		});		
 	}
 	
 	JLabel statusbar = new JLabel(); 
-	GraphView graphview;
-	ControlMGraph agc;
+	GraphView agc;
 	PView pview;
 	DataFramePanel dfp;
 	
 	private void makeContent() {
-		graphview = new GraphView(agc);
 		pview = new PView(agc);
 		dfp = new DataFramePanel(new RDataFrameRef());
 		dfp.getTable().setDefaultEditor(CellValue.class, new CellEditorE(agc));
 		JSplitPane splitPane2 = new JSplitPane(JSplitPane.VERTICAL_SPLIT, new JScrollPane(dfp), pview);
-		JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, graphview, splitPane2);
+		JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, agc, splitPane2);
 		this.getContentPane().add(splitPane);		
 	}
 
 	public static void main(String[] args) {
-		new CreateGraphGUI("graph", true, 10);
+		new CreateGraphGUI("graph", new double[] {}, true, 10);
 	}
 
 	public void windowActivated(WindowEvent e) {}
@@ -102,7 +105,7 @@ public class CreateGraphGUI extends JFrame implements WindowListener {
 	}
 
 	public GraphView getGraphView() {		
-		return graphview;
+		return agc;
 	}
 
 	public DataTable getDataTable() {		
