@@ -61,7 +61,7 @@ public class RControl {
 				//rcs.eval(".setenv <- if (exists(\"Sys.setenv\")) Sys.setenv else Sys.putenv");
 				//rcs.eval(".setenv(\"JAVAGD_CLASS_NAME\"=\"org/mutoss/gui/JavaGD\")");
 				//rcs.eval("require(JavaGD)");					
-				rcs.eval("require(gMCP)");
+				rcs.eval("require(gMCP)");				
 				//rcs.eval("graph <- createGraphFromBretzEtAl()");
 				//rcs.eval("graph <- createBonferroniHolmGraph(5)");
 				//rcs.eval("graph <- createGraphForImprovedParallelGatekeeping()");
@@ -71,6 +71,10 @@ public class RControl {
 		}
 		if (System.getProperty("eclipse") == null && !debug) System.setOut(new PrintStream(new LoggingOutputStream(logger), true));
 	}
+	
+	public static String getFraction(Double d) {
+		return  RControl.getR().eval("as.character(fractions("+d+"))").asRChar().getData()[0];
+	}
 
 }
 
