@@ -10,7 +10,7 @@ public class RDataFrameRef {
 	Vector<Vector<Double>> data = new Vector<Vector<Double>>();  
 	
 	public RDataFrameRef () {
-		addRowCol("H1");
+		//addRowCol("H1");
 	}
 
 	public String getColName(int col) {
@@ -21,10 +21,6 @@ public class RDataFrameRef {
 		return rcNames.get(row);
 	}
 
-	public void setVarName(String oldName, String newName) {
-		
-	}
-
 	public void setValue(int row, int col, Double value) {
 		data.get(row).set(col, value);
 	}
@@ -40,8 +36,6 @@ public class RDataFrameRef {
 	public double getElement(int row, int col) {
 		return data.get(row).get(col);
 	}
-
-
 	
 	public void delRowCol(int col) {
 		rcNames.remove(col); 
@@ -68,6 +62,4 @@ public class RDataFrameRef {
 		System.out.println("Data has "+getRowCount()+" rows and "+getColumnCount()+" columns now.");
 	}
 
-
-
 }
